{% extends "base.html" %}
{% block meta_title %}Déconnexion{% endblock %}

{% block title %}Déconnexion{% endblock %}

{% block main %}

<p>Merci d’avoir passé ce moment avec nous.<br/>
Vous pouvez vous identifiez à nouveau <a href="/client/login/">en cliquant ici</a>.</p>

{% endblock %}