{% extends "base.html" %}
{% load i18n %}

{% block meta_title %}{% trans "Page not found" %}{% endblock %}
      
    
{% block title %}{% trans "Page not found" %}{% endblock %}
        
{% block content %}
  {% trans "The requested page can't be found on the server" %}    
{% endblock %}

