{% load i18n %}

      {% load comments %}
      <form action="{% comment_form_target %}" method="post">{% csrf_token %}
        {% if next %}<input type="hidden" name="next" value="{{ next }}" />{% endif %}
        {% if form.errors %}
        <h4>{% blocktrans count form.errors|length as counter %}Please correct the error below{% plural %}Please correct the errors below{% endblocktrans %}</h4>
        {% else %}
        <h4>{% trans "Preview your comment" %}</h4>
          <blockquote>{{ comment|linebreaks }}</blockquote>
          <p>
          {% trans "and" %} <input type="submit" name="submit" class="submit-post" value="{% trans "Post your comment" %}" id="submit" /> {% trans "or make changes" %}:
          </p>
        {% endif %}
        {% for field in form %}
          {% if field.is_hidden %}
            {{ field }}
          {% else %}
            {% if field.errors %}{{ field.errors }}{% endif %}
            <p{% if field.errors %} class="error"{% endif %}{% ifequal field.name "honeypot" %} style="display:none;"{% endifequal %}>
              {{ field.label_tag }} {{ field }}
            </p>
          {% endif %}
        {% endfor %}
        <p class="submit">
        <input type="submit" name="submit" class="submit-post" value="{% trans "Post" %}" />
        <input type="submit" name="preview" class="submit-preview" value="{% trans "Preview" %}" />
        </p>
      </form>
