{% extends "base.html" %}
{% block content %}
<style>
.wrapper {
	height:390px;
}
</style>
<h1>WebID auth demo</h1>
<p>Ready to try your WebID? <a href="https://webidauth.rhizolab.org/test/login">Give it a try!</a></p>
<p>Do not have one yet? <a href="http://webid.rhizolab.org">Get one!</a></p>
{% endblock %}
