{% extends "base.html" %}
{% load i18n %}

{% block title %}{% trans 'Password reset successful' %}{% endblock %}

{% block main %}

<p>{% trans "We've e-mailed you instructions for setting your password to the e-mail address you submitted. You should be receiving it shortly." %}</p>

{% endblock %}