<html>
	<body>
		<h1>test</h1>
		<p>html template for webid profile</p>
		<p>Here you would see a html version of the profile. Try <pre>"accept: application/rdf+xml"</pre> for the real thing.</p>
	</body>
</html>
