{% extends "base.html" %}
{% load i18n %}

{% block title %}Remise à zéro du mot de passe{% endblock %}
{% block main %}

{% if form.errors %}
    <p>Les deux mots de passe étaient différents, merci de recommencer.</p>
{% endif %}

{% if validlink %}

<p><b>{% trans 'Enter new password' %}</b><br/>
{% trans "Please enter your new password twice so we can verify you typed it in correctly." %}</p>




<form action="" method="post" class="reg">{% csrf_token %}
<fieldset>
{{ form.new_password1.errors }}
<p class="aligned wide"><label for="id_new_password1">{% trans 'New password:' %}</label>{{ form.new_password1 }}</p>
{{ form.new_password2.errors }}
<p class="aligned wide"><label for="id_new_password2">{% trans 'Confirm password:' %}</label>{{ form.new_password2 }}</p>
<p><input type="submit" value="{% trans 'Change my password' %}" /></p>
</fieldset>
</form>

{% else %}

<h1>{% trans 'Password reset unsuccessful' %}</h1>

<p>{% trans "The password reset link was invalid, possibly because it has already been used.  Please request a new password reset." %}</p>

{% endif %}

{% endblock %}
