{% extends "base.html" %}
{% block title %}Remise à zéro du mot de passe{% endblock %}
{% block main %}

{% if form.errors %}
    <p>Désolé, mais cet email est inconnu sur notre site...<br/>
    Vous pouvez contactez l'assistance technique par téléphone au 04.27.86.84.37, ou <a href="mailto:web@quinode.fr">par e-mail</a>.</p>
{% endif %}

<form method="post" action="{% url django.contrib.auth.views.password_reset %}" class="reg">
<fieldset class="client">    
    {{ form.as_p }}
    <p><label></label><input class="bouton" type="submit" value="Valider" /></p>
    {% csrf_token %}
    <input type="hidden" name="next" value="{{ next }}" />
</fieldset>
</form>


<p><a href="/">Retour à la page d’accueil</a></p>


{% endblock %}
